<?php

namespace Drupal\blizz_vanisher\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SettingsForm.
 *
 * @package Drupal\blizz_vanisher\Form
 */
class SettingsForm extends ConfigFormBase {

  const SETTINGS_NAME = 'blizz_vanisher.settings';

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['hashtag'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Hashtag'),
      '#description' => $this->t('Automatically open the panel with the hashtag.'),
      '#default_value' => $this->config(self::SETTINGS_NAME)->get('hashtag') ?: '',
    ];

    $form['high_privacy'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('High Privacy'),
      '#description' => $this->t('Disabling the auto consent feature on navigation?'),
      '#default_value' => $this->config(self::SETTINGS_NAME)->get('high_privacy') ? TRUE : FALSE,
    ];

    $form['orientation'] = [
      '#type' => 'radios',
      '#title' => $this->t('Orientation'),
      '#description' => $this->t('The orientation of the big banner.'),
      '#default_value' => $this->config(self::SETTINGS_NAME)->get('orientation') ?: 'top',
      '#options' => [
        'top' => $this->t('Top'),
        'bottom' => $this->t('Bottom'),
      ],
    ];

    $form['adblocker'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Ad-Blocker'),
      '#description' => $this->t('Display a message if an adblocker is detected.'),
      '#default_value' => $this->config(self::SETTINGS_NAME)->get('adblocker') ? TRUE : FALSE,
    ];

    $form['show_alert_small'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show Alert Small'),
      '#description' => $this->t('Show the small banner on bottom right?'),
      '#default_value' => $this->config(self::SETTINGS_NAME)->get('show_alert_small') ? TRUE : FALSE,
    ];

    $form['cookieslist'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Cookies List'),
      '#description' => $this->t('Display the list of cookies installed?'),
      '#default_value' => $this->config(self::SETTINGS_NAME)->get('cookieslist') ? TRUE : FALSE,
    ];

    $form['remove_credit'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Remove Credit'),
      '#description' => $this->t('Remove the credit link?'),
      '#default_value' => $this->config(self::SETTINGS_NAME)->get('remove_credit') ? TRUE : FALSE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory()->getEditable(self::SETTINGS_NAME)
      ->set('hashtag', $form_state->getValue('hashtag', ''))
      ->set('high_privacy', $form_state->getValue('high_privacy', FALSE))
      ->set('orientation', $form_state->getValue('orientation', 'top'))
      ->set('adblocker', $form_state->getValue('adblocker', FALSE))
      ->set('show_alert_small', $form_state->getValue('show_alert_small', FALSE))
      ->set('cookieslist', $form_state->getValue('cookieslist', FALSE))
      ->set('remove_credit', $form_state->getValue('remove_credit', FALSE))
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * Gets the configuration names that will be editable.
   *
   * @return array
   *   An array of configuration object names that are editable if called in
   *   conjunction with the trait's config() method.
   */
  protected function getEditableConfigNames() {
    return [
      self::SETTINGS_NAME,
    ];
  }

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'blizz_vanisher.settings_form';
  }

}
